==> qtjambi-debuginfo-linux-x64-5.15.17.jar: sources/QtJambiCore/QStringListModel_shell.h <==
#ifndef QSTRINGLISTMODEL_SHELL_H
#define QSTRINGLISTMODEL_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED

#include <qtcore-config.h>
#if QT_CONFIG(stringlistmodel)
#include <QtCore/qstringlistmodel.h>
#endif //QT_CONFIG(stringlistmodel)
#include <QtJambi/QtJambiAPI>
#include <QtCore/QHash>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtCore/QVector>
#if QT_CONFIG(itemmodel)
#include <QtCore/qabstractitemmodel.h>
#endif //QT_CONFIG(itemmodel)
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qdatastream.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qmimedata.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qregexp.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qsize.h>
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtJambi/RegistryAPI>


#if QT_CONFIG(stringlistmodel)

class QStringListModel_shell : public QStringListModel, public QtJambiShellInterface
{
public:
    QStringListModel_shell(QObject* parent0 = nullptr);
    QStringListModel_shell(const QStringList& strings0, QObject* parent1 = nullptr);
    ~QStringListModel_shell() override;

    QModelIndex buddy(const QModelIndex& index0) const override;
    bool canDropMimeData(const QMimeData* data0, Qt::DropAction action1, int row2, int column3, const QModelIndex& parent4) const override;
    bool canFetchMore(const QModelIndex& parent0) const override;
    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    QVariant data(const QModelIndex& index0, int role1) const override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool dropMimeData(const QMimeData* data0, Qt::DropAction action1, int row2, int column3, const QModelIndex& parent4) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void fetchMore(const QModelIndex& parent0) override;
    Qt::ItemFlags flags(const QModelIndex& index0) const override;
    QVariant headerData(int section0, Qt::Orientation orientation1, int role2) const override;
    QModelIndex index(int row0, int column1, const QModelIndex& parent2) const override;
    bool insertColumns(int column0, int count1, const QModelIndex& parent2) override;
    bool insertRows(int row0, int count1, const QModelIndex& parent2) override;
    QMap<int, QVariant> itemData(const QModelIndex& index0) const override;
    QList<QModelIndex> match(const QModelIndex& start0, int role1, const QVariant& value2, int hits3, Qt::MatchFlags flags4) const override;
    QMimeData* mimeData(const QList<QModelIndex>& indexes0) const override;
    QStringList mimeTypes() const override;
    bool moveColumns(const QModelIndex& sourceParent0, int sourceColumn1, int count2, const QModelIndex& destinationParent3, int destinationChild4) override;
    bool moveRows(const QModelIndex& sourceParent0, int sourceRow1, int count2, const QModelIndex& destinationParent3, int destinationChild4) override;
    bool removeColumns(int column0, int count1, const QModelIndex& parent2) override;
    bool removeRows(int row0, int count1, const QModelIndex& parent2) override;
    void revert() override;
    QHash<int, QByteArray> roleNames() const override;
    int rowCount(const QModelIndex& parent0) const override;
    bool setData(const QModelIndex& index0, const QVariant& value1, int role2) override;
    bool setHeaderData(int section0, Qt::Orientation orientation1, const QVariant& value2, int role3) override;
    bool setItemData(const QModelIndex& index0, const QMap<int, QVariant>& roles1) override;
    QModelIndex sibling(int row0, int column1, const QModelIndex& idx2) const override;
    void sort(int column0, Qt::SortOrder order1) override;
    QSize span(const QModelIndex& index0) const override;
    bool submit() override;
    Qt::DropActions supportedDragActions() const override;
    Qt::DropActions supportedDropActions() const override;
    void timerEvent(QTimerEvent* event0) override;
    void resetInternalData();
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QStringListModel_access : public QStringListModel
{
    jobject __qt_data_cref_QModelIndex_int_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID index0, jint role1) const;
    jint __qt_flags_cref_QModelIndex_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID index0) const;
    jboolean __qt_insertRows_int_int_cref_QModelIndex(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint row0, jint count1, QtJambiNativeID parent2);
    jobject __qt_itemData_cref_QModelIndex_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID index0) const;
    jboolean __qt_moveRows_cref_QModelIndex_int_int_cref_QModelIndex_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID sourceParent0, jint sourceRow1, jint count2, QtJambiNativeID destinationParent3, jint destinationChild4);
    jboolean __qt_removeRows_int_int_cref_QModelIndex(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint row0, jint count1, QtJambiNativeID parent2);
    jint __qt_rowCount_cref_QModelIndex_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID parent0) const;
    jboolean __qt_setData_cref_QModelIndex_cref_QVariant_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID index0, jobject value1, jint role2);
    jboolean __qt_setItemData_cref_QModelIndex_cref_QMap(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID index0, jobject roles1);
    jobject __qt_sibling_int_int_cref_QModelIndex_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint row0, jint column1, QtJambiNativeID idx2) const;
    void __qt_sort_int_Qt_SortOrder(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint column0, jint order1);
    jint __qt_supportedDropActions(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
};

#endif // QT_CONFIG(stringlistmodel)
#endif // QSTRINGLISTMODEL_SHELL_H

==> qtjambi-debuginfo-linux-x64-6.5.7.jar: sources/QtJambiCore/QStringListModel_shell.h <==
#ifndef QSTRINGLISTMODEL_SHELL_H
#define QSTRINGLISTMODEL_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <qtcore-config.h>
#if QT_CONFIG(stringlistmodel)
#include <QtCore/qstringlistmodel.h>
#endif //QT_CONFIG(stringlistmodel)
#include <QtJambi/QtJambiAPI>
#include <QtCore/QHash>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#if QT_CONFIG(itemmodel)
#include <QtCore/qabstractitemmodel.h>
#endif //QT_CONFIG(itemmodel)
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qdatastream.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qmimedata.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qsize.h>
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtJambi/RegistryAPI>


#if QT_CONFIG(stringlistmodel)

class QStringListModel_shell : public QStringListModel, public QtJambiShellInterface
{
public:
    QStringListModel_shell(QObject* parent0 = nullptr);
    QStringListModel_shell(const QStringList& strings0, QObject* parent1 = nullptr);
    ~QStringListModel_shell() override;
    static void operator delete(void * ptr) noexcept;
private:
    QtJambiShell* __shell() const override final;
    friend class QStringListModel_mshell;
    friend class QStringListModel_oshell;
};


class QStringListModel_mshell : public QStringListModel_shell
{
public:
    using QStringListModel_shell::QStringListModel_shell;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
};


class QStringListModel_oshell : public QStringListModel_mshell
{
public:
    using QStringListModel_mshell::QStringListModel_mshell;
    QModelIndex buddy(const QModelIndex& index0) const override;
    bool canDropMimeData(const QMimeData* data0, Qt::DropAction action1, int row2, int column3, const QModelIndex& parent4) const override;
    bool canFetchMore(const QModelIndex& parent0) const override;
    void childEvent(QChildEvent* event0) override;
    bool clearItemData(const QModelIndex& index0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    QVariant data(const QModelIndex& index0, int role1) const override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool dropMimeData(const QMimeData* data0, Qt::DropAction action1, int row2, int column3, const QModelIndex& parent4) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void fetchMore(const QModelIndex& parent0) override;
    Qt::ItemFlags flags(const QModelIndex& index0) const override;
    QVariant headerData(int section0, Qt::Orientation orientation1, int role2) const override;
    QModelIndex index(int row0, int column1, const QModelIndex& parent2) const override;
    bool insertColumns(int column0, int count1, const QModelIndex& parent2) override;
    bool insertRows(int row0, int count1, const QModelIndex& parent2) override;
    QMap<int, QVariant> itemData(const QModelIndex& index0) const override;
    QList<QModelIndex> match(const QModelIndex& start0, int role1, const QVariant& value2, int hits3, Qt::MatchFlags flags4) const override;
    QMimeData* mimeData(const QList<QModelIndex>& indexes0) const override;
    QStringList mimeTypes() const override;
    bool moveColumns(const QModelIndex& sourceParent0, int sourceColumn1, int count2, const QModelIndex& destinationParent3, int destinationChild4) override;
    bool moveRows(const QModelIndex& sourceParent0, int sourceRow1, int count2, const QModelIndex& destinationParent3, int destinationChild4) override;
    void multiData(const QModelIndex& index0, QModelRoleDataSpan roleDataSpan1) const override;
    bool removeColumns(int column0, int count1, const QModelIndex& parent2) override;
    bool removeRows(int row0, int count1, const QModelIndex& parent2) override;
    void resetInternalData() override;
    void revert() override;
    QHash<int, QByteArray> roleNames() const override;
    int rowCount(const QModelIndex& parent0) const override;
    bool setData(const QModelIndex& index0, const QVariant& value1, int role2) override;
    bool setHeaderData(int section0, Qt::Orientation orientation1, const QVariant& value2, int role3) override;
    bool setItemData(const QModelIndex& index0, const QMap<int, QVariant>& roles1) override;
    QModelIndex sibling(int row0, int column1, const QModelIndex& idx2) const override;
    void sort(int column0, Qt::SortOrder order1) override;
    QSize span(const QModelIndex& index0) const override;
    bool submit() override;
    Qt::DropActions supportedDragActions() const override;
    Qt::DropActions supportedDropActions() const override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
private:
    jmethodID __shell_javaMethod(int pos) const;
};

struct QStringListModel_access : public QStringListModel
{
    jboolean __qt_clearItemData_cref_QModelIndex(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID index0);
    jobject __qt_data_cref_QModelIndex_int_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID index0, jint role1) const;
    jint __qt_flags_cref_QModelIndex_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID index0) const;
    jboolean __qt_insertRows_int_int_cref_QModelIndex(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint row0, jint count1, QtJambiNativeID parent2);
    jobject __qt_itemData_cref_QModelIndex_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID index0) const;
    jboolean __qt_moveRows_cref_QModelIndex_int_int_cref_QModelIndex_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID sourceParent0, jint sourceRow1, jint count2, QtJambiNativeID destinationParent3, jint destinationChild4);
    jboolean __qt_removeRows_int_int_cref_QModelIndex(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint row0, jint count1, QtJambiNativeID parent2);
    jint __qt_rowCount_cref_QModelIndex_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID parent0) const;
    jboolean __qt_setData_cref_QModelIndex_cref_QVariant_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID index0, jobject value1, jint role2);
    jboolean __qt_setItemData_cref_QModelIndex_cref_QMap(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID index0, jobject roles1);
    jobject __qt_sibling_int_int_cref_QModelIndex_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint row0, jint column1, QtJambiNativeID idx2) const;
    void __qt_sort_int_Qt_SortOrder(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint column0, jint order1);
    jint __qt_supportedDropActions_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
};

#endif // QT_CONFIG(stringlistmodel)
#endif // QSTRINGLISTMODEL_SHELL_H
